<?php
namespace CoprAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Icon Widget
 */
class Copr_Icon extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-icon';
	}
	
	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Theme Icons', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_icon_content',
			[
				'label' => esc_html__( 'Theme Icons', 'copr' ),
			]
		);
		
		$this->add_control(
			'icon_library',
			[
				'label' => esc_html__( 'Icon Library', 'copr' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-font-awesome-icons',
				'label_block' => true,
				'options' => [
					'dtr-font-awesome-icons'	=> esc_html__( 'Font Awesome Library', 'copr' ),
					'dtr-theme-custom-icons' 	=> esc_html__( 'Theme Custom Library', 'copr' ),
				],
			]
		);
		
		$this->add_control(
			'default_icon',
			[
				'label' => esc_html__( 'Font Awesome Library', 'copr' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
				'label_block' => true,
				'condition' => [
					'icon_library' => [ 'dtr-font-awesome-icons' ],
				],
			]
		);

		// custom icons
		$this->add_control(
			'custom_icon',
			[
				'label' => esc_html__( 'Theme Custom Library', 'copr' ),
				'type' => Controls_Manager::SELECT2,
				'default' => 'icon-image-solid',
				'label_block' => true,
				'condition' => [
					'icon_library'	=> [ 'dtr-theme-custom-icons' ],
				],
				'description' => esc_html__( 'Icon demo file for extra icons is included in help document.', 'copr' ),
				'options' => dtr_icons(),
			]
		);
		
		$this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'copr' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => 64,
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-icon' => 'font-size:{{SIZE}}{{UNIT}}',
				],
			]
		);
		
		$this->add_responsive_control(
			'icon_align',
			[
				'label' => esc_html__( 'Icon Alignment', 'copr' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left'    => [
						'title' => esc_html__( 'Left', 'copr' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'copr' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'copr' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'default' => 'left',
			]
		);
		
		// link
		$this->add_control(
			'icon_link_control',
			[
				'label' 	=> esc_html__( 'Link', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		

		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'copr' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default'	=> [
					'url'	=> '',
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' => esc_html__( 'View', 'copr' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => esc_html__( 'Styles', 'copr' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'copr' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-icon' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
	$settings = $this->get_settings(); 
	if ( ! empty( $settings['custom_icon'] ) ) {
		$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] . ' dtr-icon' );
		$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' );
	}
	
	// link
	if ( ! empty( $settings['link']['url'] ) ) {
		$this->add_render_attribute( 'button', 'href', $settings['link']['url'] );
		$this->add_render_attribute( 'button', 'class', 'dtr-icon-sc-link' );
		if ( $settings['link']['is_external'] ) {
			$this->add_render_attribute( 'button', 'target', '_blank' );
		}
		if ( $settings['link']['nofollow'] ) {
			$this->add_render_attribute( 'button', 'rel', 'nofollow' );
		}
	}
	$this->add_render_attribute( 'button', 'role', 'button' );
	?>
	<div class="dtr-icon-wrapper">
		<?php if ( $settings['icon_library'] == 'dtr-theme-custom-icons' ) { ?>
			<?php if ( ! empty( $settings['link']['url'] ) ) { ?>
			<a <?php echo $this->get_render_attribute_string( 'button' ); ?>>
			<?php } ?>
				<span class="dtr-icon"><i <?php echo $this->get_render_attribute_string( 'custom_icon' ) ?>></i></span>
			<?php if ( ! empty( $settings['link']['url'] ) ) { ?>
			</a>
			<?php } ?>
		<?php
		}  else { ?>
			<?php if ( ! empty( $settings['link']['url'] ) ) { ?>
			<a <?php echo $this->get_render_attribute_string( 'button' ); ?>>
			<?php } ?>
				<span class="dtr-icon"><?php Icons_Manager::render_icon( $settings['default_icon'], [ 'aria-hidden' => 'true' ] ); ?></span>
			<?php if ( ! empty( $settings['link']['url'] ) ) { ?>
			</a>
			<?php } ?>
		<?php } ?>
	</div>
<?php

	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {  
	?>
	<# iconHTML = elementor.helpers.renderIcon( view, settings.default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
	<div class="dtr-icon-wrapper"> 
		<# if ( settings.icon_library == 'dtr-theme-custom-icons' ) { #>
			<# if ( settings.link.url ) { #>
			<a class="dtr-icon-sc-link" href="{{ settings.link.url }}" role="button">
			<# } #>  
				<span class="dtr-icon"><i class="{{ settings.custom_icon }}"></i></span>
			<# if ( settings.link.url ) { #>
			</a> 
			<# } #> 
		<# } else {  #>
			<# if ( settings.link.url ) { #>
			<a class="dtr-icon-sc-link" href="{{ settings.link.url }}" role="button">
			<# } #> 
				<span class="dtr-icon">{{{ iconHTML.value }}}</span>
			<# if ( settings.link.url ) { #>
			</a> 
			<# } #> 
		<# } #> 
	</div>
<?php
	}
}